diff src/notify.h @ 10209:9e0b98c458b1

[gaim-migrate @ 11331] gaim_notify_uri now needs trusted parameter to indicate whether the source of the uri is trusted. This helps us avoid the security risks involved in blindly executing untrusted local file URIs in windows. This fixes the MSN open mail bug on windows. committer: Tailor Script <tailor@pidgin.im>
author Herman Bloggs <hermanator12002@yahoo.com>
date Fri, 19 Nov 2004 20:18:14 +0000
parents cc68a8c6e741
children 95ca0db2d01d
line wrap: on
line diff
--- a/src/notify.h	Fri Nov 19 16:42:07 2004 +0000
+++ b/src/notify.h	Fri Nov 19 20:18:14 2004 +0000
@@ -78,7 +78,7 @@
 							  const char *title, const char *primary,
 							  const char *secondary, const char *text,
 							  GCallback cb, void *user_data);
-	void *(*notify_uri)(const char *uri);
+	void *(*notify_uri)(const char *uri, gboolean trusted);
 
 	void (*close_notify)(GaimNotifyType type, void *ui_handle);
 
@@ -202,14 +202,15 @@
 /**
  * Opens a URI or somehow presents it to the user.
  *
  * @param handle The plugin or connection handle.
  * @param uri    The URI to display or go to.
  *
  * @return A UI-specific handle, if any. This may only be presented if
  *         the UI code displays a dialog instead of a webpage, or something
  *         similar.
  */
-void *gaim_notify_uri(void *handle, const char *uri);
+void *gaim_notify_uri(void *handle, const char *uri, gboolean trusted);
 
 /**
  * Closes a notification.
@@ -202,14 +202,15 @@
  * Opens a URI or somehow presents it to the user.
  *
- * @param handle The plugin or connection handle.
- * @param uri    The URI to display or go to.
+ * @param handle  The plugin or connection handle.
+ * @param uri     The URI to display or go to.
+ * @param trusted The source of the URI is trusted.
  *
  * @return A UI-specific handle, if any. This may only be presented if